@@ -25,6 +25,7 @@ int create_rectangles_obb_from_vertex_list(std::vector<Eigen::Vector2d>& verts,
 
 }  // namespace geometry_queries
 
+
 namespace detail {
 namespace geometry_queries {
 
@@ -32,9 +33,12 @@ OBB merge_obbs(const OBB& obb1, const OBB& obb2);
 
 RectangleOBBConstPtr ccd_merge_entities(const RectangleOBB* first,
                                         const RectangleOBB* second);
+
+int ccd_merge_entities(const Sphere* first,
+                       const Sphere* second, ShapeGroupPtr ret);
+
 }  // namespace geometry_queries
 }  // namespace detail
-
 }  // namespace collision
 
 #endif /* CPP_COLLISION_INCLUDE_COLLISION_SOLVERS_GEOMETRY_QUERIES_H_ */
